@@ -1,24 +1,23 @@
 // -*- c++ -*- (enables emacs c++ mode)
-//========================================================================
+//===========================================================================
 //
-// Copyright (C) 2006-2006 Yves Renard, Julien Pommier.
+// Copyright (C) 2006-2008 Yves Renard, Julien Pommier.
 //
 // This file is a part of GETFEM++
 //
-// Getfem++ is free software; you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
+// Getfem++  is  free software;  you  can  redistribute  it  and/or modify it
+// under  the  terms  of the  GNU  Lesser General Public License as published
+// by  the  Free Software Foundation;  either version 2.1 of the License,  or
+// (at your option) any later version.
+// This program  is  distributed  in  the  hope  that it will be useful,  but
+// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+// or  FITNESS  FOR  A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+// License for more details.
+// You  should  have received a copy of the GNU Lesser General Public License
+// along  with  this program;  if not, write to the Free Software Foundation,
+// Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Lesser General Public License for more details.
-// You should have received a copy of the GNU Lesser General Public
-// License along with this program; if not, write to the Free Software
-// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301,
-// USA.
-//
-//========================================================================
+//===========================================================================
 
 #include <getfemint_misc.h>
 #include <getfemint_mesh_fem.h>
@@ -31,7 +30,7 @@
 #include <getfem/getfem_partial_mesh_fem.h>
 
 /*
-  $Id: gf_mesh_fem_get.cc 2537 2007-02-02 11:44:02Z pommier $
+  $Id: gf_mesh_fem_get.cc 2722 2007-12-04 15:26:17Z renard $
 
   ChangeLog:
   $Log: gf_mesh_fem_get.cc,v $
@@ -309,7 +308,7 @@ interpolate_convex_data(const getfem::mesh_fem *pmf,
     U3=gf_mesh_fem_get(mf,'eval',[1 0]) % output has one row, only valid if qdim(mf)==2
     U4=gf_mesh_fem_get(mf,'eval',{'x';'y.*z';4;@myfunctionofxyz})
 
-  $Id: gf_mesh_fem_get.cc 2537 2007-02-02 11:44:02Z pommier $
+  $Id: gf_mesh_fem_get.cc 2722 2007-12-04 15:26:17Z renard $
 MLABCOM*/
 /*MLABEXT
   if (nargin>=2 & strcmpi(varargin{2},'eval')),
